@@ -3,13 +3,18 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use Carp ();
 use Scalar::Util ();
 
 use Sub::Meta::Param;
 
+use overload
+    fallback => 1,
+    eq => \&is_same_interface
+    ;
+
 sub _croak { require Carp; Carp::croak(@_) }
 
 sub new {
@@ -48,6 +53,7 @@ sub _normalize_args {
 
 sub _assert_nshift {
     my $self = shift;
+    return unless $self->nshift;
     if (@{$self->_all_positional_required} < $self->nshift) {
         _croak 'required positional parameters need more than nshift';
     }
@@ -110,6 +116,26 @@ sub args_max() {
     $r
 }
 
+sub is_same_interface {
+    my ($self, $other) = @_;
+
+    return unless $self->slurpy eq $other->slurpy;
+
+    return unless @{$self->args} == @{$other->args};
+    for (my $i = 0; $i < @{$self->args}; $i++) {
+        return unless $self->args->[$i]->is_same_interface($other->args->[$i]);
+    }
+
+    if (defined $self->nshift) {
+        return unless $self->nshift == $other->nshift;
+    }
+    else {
+        return if defined $other->nshift;
+    }
+
+    return 1;
+}
+
 1;
 __END__
 
@@ -251,6 +277,17 @@ This is computed as follows:
   If there are any named or slurpy parameters, the result is Inf.
   Otherwise the result is the number of all invocants and positional parameters.
 
+=head2 is_same_interface($other_meta)
+
+A boolean value indicating whether C<Sub::Meta::Parameters> object is same or not.
+Specifically, check whether C<args>, C<nshift> and C<slurpy> are equal.
+
+=head1 SEE ALSO
+
+L<Function::Parameters::Info>.
+
+The methods in this module are almost copied from the C<Function::Parameters::Info> methods.
+
 =head1 LICENSE
 
 Copyright (C) kfly8.
